#!/bin/bash
#

#
# lxml is a product that is always built unqualified
#
# build_lxml.sh  <product_directory> [tar]

usage()
{
   echo "USAGE: `basename ${0}` <product_directory> [<p2714 | p2714b | p2715 | p2715a | p371 | p372>] [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
basequal=${2}
maketar=${3}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

if [[ "${basequal}" == "tar" ]]
then
  basequal=""
  maketar=tar
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=lxml
origpkgver=v4_3_0
pkgver=${origpkgver}
ssibuildshims_version=v1_04_13
pkgdotver=`echo ${origpkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`
pkgtarname=${package}-${pkgdotver}
make_tarball_opts=("${product_dir}" "${package}" "${pkgver}" "${basequal:-NO_QUAL}")
get_this_dir
get_ssibuildshims

if [[ -n "${basequal}" ]]; then
  dbflag=NO_TYPE
else
  dbflag=NO_QUAL
fi
source define_basics ${dbflag} NO_DEBUG_SOURCE

if [ "${maketar}" = "tar" ] && [ -f "${product_dir}/${package}/${pkgver}.version/${flvr}_${basequal}" ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball "${make_tarball_opts[@]}"
   exit 0
fi

echo "building ${package} for ${OS}-${plat}"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

mkdir -p ${blddir} 
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi

if [ ${OS1} = "Darwin" ]
then
   PATH=`dropit /usr/bin/get-cert $PATH`
fi

# declare now so we can setup
# fake ups declare
fakedb=${product_dir}/${package}/${pkgver}/fakedb
${SSIBUILDSHIMS_DIR}/bin/fake_declare_product ${product_dir} ${package} ${pkgver} ${basequal:-NO_QUAL} || \
  ssi_die "fake declare failed"

# setup
setup -B ${package} ${pkgver} ${basequal:+-q ${basequal}} -z ${fakedb}:${product_dir}:${PRODUCTS} || ssi_die "fake setup failed"

set -x

# work in a build directory, which will not be part of any distribution
cd ${blddir} || ssi_die "Unable to cd into ${blddir}"
tar xf ${tardir}/${pkgtarname}.tar.gz || ssi_die "Failed to untar ${pkgtarname}.tar.gz"
cd ${package}-${pkgdotver} || ssi_die "Failed to cd into ${package}-${pkgdotver}"

# Python short version for use in paths.
if [[ -n "$PYTHON_VERSION" ]]; then
  python_shortdotversion=${PYTHON_VERSION#v}
  python_shortdotversion=${python_shortdotversion//_/.}
  python_shortdotversion=${python_shortdotversion%.*}
else
  python_shortdotversion=$(python --version 2>&1 | sed -e 's&Python \([0-9]\)\.\([0-9]\{1,\}\).*$&\1.\2&')
fi

site_packages_dir="${pkgdir}/lib/python${python_shortdotversion}/site-packages"
mkdir -p ${site_packages_dir} || ssi_die "Failed to create the site_packages directory ${site_packages_dir}"

python setup.py install --prefix ${pkgdir} --install-lib "${site_packages_dir}" || \
  ssi_die "python setup.py install failed for $package"

set +x

if [ ! -d ${pkgdir}/lib ]
then
   echo "ERROR: failed to create ${pkgdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# real ups declare
${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} ${basequal:-NO_QUAL} || \
  ssi_die "failed to declare ${package} ${pkgver}"

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup -B ${package} ${pkgver} ${basequal:+-q ${basequal}} -z ${product_dir}
echo "lxml is installed at ${LXML_DIR}"

# this must be last
set -x
if [ "${maketar}" = "tar" ] && [ -f "${product_dir}/${package}/${pkgver}.version/${flvr}_${basequal}" ]
then
  ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball "${make_tarball_opts[@]}"
fi

exit 0
